@@ -5,25 +5,26 @@ import distutils
 import os
 import os.path
 import pkg_resources
+
+try:
+    import pathlib
+except ImportError:
+    import pathlib2 as pathlib  # Python 2.7
+
 import py.path
 import re
 import requests
 import six
 import subprocess
 import sys
-import wheel
 
 from contextlib import contextmanager
 from mock import patch
-from pkg_resources import parse_version
 
-from skbuild import __version__ as skbuild_version
 from skbuild.compat import which  # noqa: F401
 from skbuild.utils import push_dir
 from skbuild.platform_specifics import get_platform
 
-from zipfile import ZipFile
-
 
 SAMPLES_DIR = os.path.join(
     os.path.dirname(os.path.realpath(__file__)),
@@ -102,40 +103,58 @@ def _tmpdir(basename):
                                            lock_timeout=None)
 
 
-def _copy_dir(target_dir, entry, on_duplicate='exception', keep_top_dir=False):
+def _copy(src, target):
+    """
+    Copies a single entry (file, dir) named 'src' to 'target'. Softlinks are
+    processed properly as well.
 
-    if isinstance(entry, six.string_types):
-        entry = py.path.local(entry)
+    Copied from pytest-datafiles/pytest_datafiles.py (MIT License)
+    """
+    if not src.exists():
+        raise ValueError("'%s' does not exist!" % src)
+
+    if src.isdir():
+        src.copy(target / src.basename)
+    elif src.islink():
+        (target / src.basename).mksymlinkto(src.realpath())
+    else:  # file
+        src.copy(target)
+
+
+def _copy_dir(target_dir, src_dir, on_duplicate='exception', keep_top_dir=False):
+    """
+    Copies all entries (files, dirs) from 'src_dir' to 'target_dir' taking
+    into account the 'on_duplicate' option (which defines what should happen if
+    an entry already exists: raise an exception, overwrite it or ignore it).
+
+    Adapted from pytest-datafiles/pytest_datafiles.py (MIT License)
+    """
+    src_files = []
+
+    if isinstance(src_dir, six.string_types):
+        src_dir = py.path.local(src_dir)
 
-    # Copied from pytest-datafiles/pytest_datafiles.py (MIT License)
-    basename = entry.basename
     if keep_top_dir:
-        if on_duplicate == 'overwrite' or not (target_dir / basename).exists():
-            entry.copy(target_dir / basename)
+        src_files = src_dir
+    else:
+        if src_dir.isdir():
+            src_files.extend(src_dir.listdir())
+        else:
+            src_files.append(src_dir)
+
+    for entry in src_files:
+        target_entry = target_dir / entry.basename
+        if not target_entry.exists() or on_duplicate == 'overwrite':
+            _copy(entry, target_dir)
         elif on_duplicate == 'exception':
             raise ValueError(
-                "'%s' already exists (entry %s)" % (basename, entry)
+                "'%s' already exists (src %s)" % (
+                    target_entry,
+                    entry,
                 )
-        # else: on_duplicate == 'ignore': do nothing with entry
-    else:
-        # Regular directory (no keep_top_dir). Need to check every file
-        # for duplicates
-        if on_duplicate == 'overwrite':
-            entry.copy(target_dir)
-            return
-        for sub_entry in entry.listdir():
-            if not (target_dir / sub_entry.basename).exists():
-                sub_entry.copy(target_dir / sub_entry.basename)
-                continue
-            if on_duplicate == 'exception':
-                # target exists
-                raise ValueError(
-                    "'%s' already exists (entry %s)" % (
-                        (target_dir / sub_entry.basename),
-                        sub_entry,
-                        )
-                    )
-            # on_duplicate == 'ignore': do nothing with e2
+            )
+        else:  # ignore
+            continue
 
 
 def initialize_git_repo_and_commit(project_dir, verbose=True):
@@ -294,46 +313,7 @@ def is_site_reachable(url):
         return False
 
 
-def check_wheel_content(wheel_archive, expected_distribution_name, expected_content, pure=False):
-    """This function raises an AssertionError if the given wheel_archive
-    does not have the expected content.
-
-    Note that this function already takes care of appending the
-    ``<expected_distribution_name>.dist-info`` files to the ``expected_content``
-    list.
+def list_ancestors(path):
+    """Return logical ancestors of the path.
     """
-
-    expected_content = list(expected_content)
-    expected_content += [
-        '%s.dist-info/top_level.txt' % expected_distribution_name,
-        '%s.dist-info/WHEEL' % expected_distribution_name,
-        '%s.dist-info/RECORD' % expected_distribution_name,
-        '%s.dist-info/METADATA' % expected_distribution_name
-    ]
-
-    if parse_version(wheel.__version__) < parse_version('0.31.0'):
-        expected_content += [
-            '%s.dist-info/DESCRIPTION.rst' % expected_distribution_name,
-            '%s.dist-info/metadata.json' % expected_distribution_name
-        ]
-
-    if pure:
-        assert wheel_archive.endswith('-none-any.whl')
-    else:
-        assert not wheel_archive.endswith('-none-any.whl')
-
-    archive = ZipFile(wheel_archive)
-    member_list = archive.namelist()
-
-    assert sorted(expected_content) == sorted(member_list)
-
-    # PEP-0427: Generator is the name and optionally the version of the
-    # software that produced the archive.
-    # See https://www.python.org/dev/peps/pep-0427/#file-contents
-    current_generator = None
-    with archive.open("%s.dist-info/WHEEL" % expected_distribution_name) as wheel_file:
-        for line in wheel_file:
-            if line.startswith(b"Generator"):
-                current_generator = line.split(b":")[1].strip()
-                break
-    assert current_generator == six.b("skbuild %s" % skbuild_version)
+    return [str(parent) for parent in pathlib.PurePosixPath(path).parents if str(parent) != "."]
