@@ -10,12 +10,13 @@ Tests for various command line functionality.
 import os
 import pytest
 
+from skbuild.exceptions import SKBuildError
 from skbuild.utils import push_dir, to_platform_path
 
 from . import project_setup_py_test
 
 
-@project_setup_py_test("hello", ["--help"])
+@project_setup_py_test("hello-no-language", ["--help"], disable_languages_test=True)
 def test_help(capsys):
     out, err = capsys.readouterr()
     assert "scikit-build options" not in out
@@ -23,7 +24,7 @@ def test_help(capsys):
     assert "usage:" in out
 
 
-@project_setup_py_test("hello", ["--help-commands"])
+@project_setup_py_test("hello-no-language", ["--help-commands"], disable_languages_test=True)
 def test_help_commands(capsys):
     out, err = capsys.readouterr()
     assert "scikit-build options" in out
@@ -32,20 +33,20 @@ def test_help_commands(capsys):
     assert "usage:" in out
 
 
-@project_setup_py_test("hello", ["--author", "--name"])
+@project_setup_py_test("hello-no-language", ["--author", "--name"], disable_languages_test=True)
 def test_metadata_display(capsys):
     out, err = capsys.readouterr()
     assert "scikit-build options" not in out
     assert "Global options:" not in out
     assert "usage:" not in out
     assert "The scikit-build team" == out.splitlines()[0]
-    assert "hello" == out.splitlines()[1]
+    assert "hello_no_language" == out.splitlines()[1]
 
 
 def test_no_command():
     with push_dir():
 
-        @project_setup_py_test("hello", [])
+        @project_setup_py_test("hello-no-language", [], disable_languages_test=True)
         def run():
             pass
 
@@ -63,7 +64,7 @@ def test_invalid_command():
 
     with push_dir():
 
-        @project_setup_py_test("hello", ["unknown"])
+        @project_setup_py_test("hello-no-language", ["unknown"], disable_languages_test=True)
         def run():
             pass
 
@@ -80,7 +81,7 @@ def test_invalid_command():
 def test_too_many_separators():
     with push_dir():
 
-        @project_setup_py_test("hello", ["--"] * 3)
+        @project_setup_py_test("hello-no-language", ["--"] * 3, disable_languages_test=True)
         def run():
             pass
 
@@ -93,23 +94,44 @@ def test_too_many_separators():
         assert failed
 
 
-@project_setup_py_test("hello",
-                       ["build", "--", "-DMY_CMAKE_VARIABLE:BOOL=1"])
+@project_setup_py_test("hello-no-language",
+                       ["build", "--", "-DMY_CMAKE_VARIABLE:BOOL=1"], disable_languages_test=True)
 def test_cmake_args(capfd):
     out, err = capfd.readouterr()
     assert "Manually-specified variables were not used by the project" in err
     assert "MY_CMAKE_VARIABLE" in err
 
 
+def test_cmake_executable_arg():
+
+    cmake_executable = "/path/to/invalid/cmake"
+
+    @project_setup_py_test("hello-no-language",
+                           ["--cmake-executable", cmake_executable, "build"], disable_languages_test=True)
+    def should_fail():
+        pass
+
+    failed = False
+    message = ""
+    try:
+        should_fail()
+    except SystemExit as e:
+        failed = isinstance(e.code, SKBuildError)
+        message = str(e)
+
+    assert failed
+    assert "Problem with the CMake installation, aborting build. CMake executable is %s" % cmake_executable in message
+
+
 @pytest.mark.parametrize("action", ['sdist', 'bdist_wheel'])
 @pytest.mark.parametrize("hide_listing", [True, False])
-def test_sdist_hide_listing(action, hide_listing, capfd):
+def test_hide_listing(action, hide_listing, capfd):
 
-    cmd = [action, "--", "-DMY_CMAKE_VARIABLE:BOOL=1"]
+    cmd = [action]
     if hide_listing:
         cmd.insert(0, "--hide-listing")
 
-    @project_setup_py_test("hello", cmd, verbose_git=False)
+    @project_setup_py_test("test-hide-listing", cmd, verbose_git=False, disable_languages_test=True)
     def run():
         pass
 
@@ -122,23 +144,20 @@ def test_sdist_hide_listing(action, hide_listing, capfd):
         assert to_platform_path("bonjour/__init__.py") in out
 
     if action == "sdist":
-        what = "copied"
-        if hasattr(os, 'link'):
-            what = "hard-linked"
-        assert "%s 8 files" % what in out
+        assert "copied 10 files" in out
     elif action == "bdist_wheel":
         assert "copied 6 files" in out  # build_py
-        assert "copied 7 files" in out  # install_lib
+        assert "copied 9 files" in out  # install_lib
         assert "copied 0 files" in out  # install_scripts
 
 
-@project_setup_py_test("hello", ["--force-cmake", "--help"])
+@project_setup_py_test("hello-no-language", ["--force-cmake", "--help"], disable_languages_test=True)
 def test_run_cmake_arg(capfd):
     out, _ = capfd.readouterr()
     assert "Generating done" in out
 
 
-@project_setup_py_test("hello", ["--skip-cmake", "build"])
+@project_setup_py_test("hello-no-language", ["--skip-cmake", "build"], disable_languages_test=True)
 def test_skip_cmake_arg(capfd):
     out, _ = capfd.readouterr()
     assert "Generating done" not in out
