@@ -11,15 +11,13 @@ import glob
 import os
 import pytest
 import sysconfig
-import tarfile
 
 from skbuild.constants import CMAKE_BUILD_DIR, CMAKE_INSTALL_DIR, SKBUILD_DIR
 from skbuild.utils import push_dir
 
-from zipfile import ZipFile
-
-from . import check_wheel_content, project_setup_py_test
+from . import project_setup_py_test
 from . import (_copy_dir, _tmpdir, SAMPLES_DIR)
+from .pytest_helpers import check_sdist_content, check_wheel_content
 
 
 def test_hello_builds():
@@ -63,24 +61,13 @@ def test_hello_sdist():
         'hello-1.2.3/hello/__init__.py',
         'hello-1.2.3/hello/__main__.py',
         'hello-1.2.3/setup.py',
-        'hello-1.2.3/PKG-INFO'
     ]
 
-    member_list = None
+    sdist_archive = 'dist/hello-1.2.3.zip'
     if sdists_tar:
-        expected_content.extend([
-            'hello-1.2.3',
-            'hello-1.2.3/bonjour',
-            'hello-1.2.3/bonjour/data',
-            'hello-1.2.3/hello'
-        ])
-        member_list = tarfile.open('dist/hello-1.2.3.tar.gz').getnames()
+        sdist_archive = 'dist/hello-1.2.3.tar.gz'
 
-    elif sdists_zip:
-        member_list = ZipFile('dist/hello-1.2.3.zip').namelist()
-
-    assert expected_content and member_list
-    assert sorted(expected_content) == sorted(member_list)
+    check_sdist_content(sdist_archive, 'hello-1.2.3', expected_content)
 
 
 def test_hello_wheel():
@@ -107,14 +94,14 @@ def test_hello_wheel():
         os.remove(whls[0])
         assert not os.path.exists(whls[0])
 
-        assert os.path.exists(os.path.join(CMAKE_BUILD_DIR, "CMakeCache.txt"))
-        os.remove(os.path.join(CMAKE_BUILD_DIR, "CMakeCache.txt"))
+        assert os.path.exists(os.path.join(CMAKE_BUILD_DIR(), "CMakeCache.txt"))
+        os.remove(os.path.join(CMAKE_BUILD_DIR(), "CMakeCache.txt"))
 
     tmp_dir = build_wheel()[0]
 
     @project_setup_py_test("hello-cpp", ["--skip-cmake", "bdist_wheel"], tmp_dir=tmp_dir)
     def build_wheel_skip_cmake():
-        assert not os.path.exists(os.path.join(CMAKE_BUILD_DIR, "CMakeCache.txt"))
+        assert not os.path.exists(os.path.join(CMAKE_BUILD_DIR(), "CMakeCache.txt"))
         whls = glob.glob('dist/*.whl')
         assert len(whls) == 1
         check_wheel_content(whls[0], expected_distribution_name, expected_content)
@@ -134,7 +121,7 @@ def test_hello_clean(dry_run, capfd):
 
         tmp_dir = run_build()[0]
 
-        assert tmp_dir.join(SKBUILD_DIR).exists()
+        assert tmp_dir.join(SKBUILD_DIR()).exists()
 
         # XXX Since using capfd.disabled() context manager prevents
         # the output from being captured atfer it exits, we display
@@ -152,9 +139,9 @@ def test_hello_clean(dry_run, capfd):
         run_clean()
 
         if not dry_run:
-            assert not tmp_dir.join(SKBUILD_DIR).exists()
+            assert not tmp_dir.join(SKBUILD_DIR()).exists()
         else:
-            assert tmp_dir.join(SKBUILD_DIR).exists()
+            assert tmp_dir.join(SKBUILD_DIR()).exists()
 
         build_out, clean_out = capfd.readouterr()[0].split('<<-->>')
         assert 'Build files have been written to' in build_out
@@ -190,9 +177,9 @@ def test_hello_cleans(capfd):
     clean2_out = clean2_out.strip()
 
     assert "running clean" == clean1_out.splitlines()[0]
-    assert "removing '{}'".format(CMAKE_INSTALL_DIR) == clean1_out.splitlines()[1]
-    assert "removing '{}'".format(CMAKE_BUILD_DIR) == clean1_out.splitlines()[2]
-    assert "removing '{}'".format(SKBUILD_DIR) == clean1_out.splitlines()[3]
+    assert "removing '{}'".format(CMAKE_INSTALL_DIR()) == clean1_out.splitlines()[1]
+    assert "removing '{}'".format(CMAKE_BUILD_DIR()) == clean1_out.splitlines()[2]
+    assert "removing '{}'".format(SKBUILD_DIR()) == clean1_out.splitlines()[3]
 
     assert "running clean" == clean2_out
 
