@@ -8,6 +8,7 @@ Tests for platforms, to verify that CMake correctly does a test compilation.
 """
 
 import os
+import sys
 import platform
 import pytest
 
@@ -34,8 +35,6 @@ def test_write_compiler_test_file():
         # verify that the test file exists (it's not valid, because it has no
         # languages)
         assert(os.path.exists(os.path.join(test_folder, "CMakeLists.txt")))
-    except:
-        raise
     finally:
         skbuild_platform.cleanup_test()
 
@@ -57,8 +56,6 @@ def test_cxx_compiler():
     try:
         assert(generator is not None)
         assert not os.path.exists(test_build_folder)
-    except:
-        raise
     finally:
         skbuild_platform.cleanup_test()
 
@@ -76,8 +73,6 @@ def test_fortran_compiler():
     # doesn't actually compile anything.
     try:
         assert(generator is not None)
-    except:
-        raise
     finally:
         skbuild_platform.cleanup_test()
 
@@ -115,3 +110,12 @@ def test_unsupported_platform(mocker):
 
     assert failed
     assert "Unsupported platform: bogus." in message
+
+
+@pytest.mark.skipif(sys.platform != 'win32', reason='Requires Windows')
+def test_cached_generator():
+    platform = get_platform()
+    generator = platform.get_generator('Ninja')
+    env = generator.env
+
+    assert 'Visual Studio' in env['LIB'] or 'Visual C++' in env['LIB']
