@@ -10,6 +10,7 @@ Tests for `skbuild.setup` function.
 import textwrap
 import os
 import pprint
+import py.path
 import pytest
 
 from distutils.core import Distribution as distutils_Distribution
@@ -24,7 +25,7 @@ from skbuild.setuptools_wrap import strip_package
 from skbuild.utils import (push_dir, to_platform_path)
 
 from . import (_tmpdir, execute_setup_py,
-               initialize_git_repo_and_commit, push_argv)
+               initialize_git_repo_and_commit, is_site_reachable, push_argv)
 
 
 @pytest.mark.parametrize("distribution_type",
@@ -60,7 +61,7 @@ def test_distribution_is_pure(distribution_type, tmpdir):
             cmake_minimum_required(VERSION 3.5.0)
             project(test NONE)
             install(CODE "execute_process(
-              COMMAND \${CMAKE_COMMAND} -E sleep 0)")
+              COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
             """
         )
     else:
@@ -120,7 +121,7 @@ def test_cmake_args_keyword(cmake_args, capfd):
         message(STATUS "VAR[${VAR}]")
         message(STATUS "VAR_WITH_SPACE[${VAR_WITH_SPACE}]")
         install(CODE "execute_process(
-          COMMAND \${CMAKE_COMMAND} -E sleep 0)")
+          COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
         """
     ))
 
@@ -141,7 +142,7 @@ def test_cmake_args_keyword(cmake_args, capfd):
     "cmake_install_dir, expected_failed, error_code_type", (
         (None, True, str),
         ('', True, str),
-        (os.getcwd(), True, SKBuildError),
+        (str(py.path.local.get_temproot().join('scikit-build')), True, SKBuildError),
         ('banana', False, str)
     )
 )
@@ -172,7 +173,7 @@ def test_cmake_install_dir_keyword(
 
     setup_kwarg = ''
     if cmake_install_dir is not None:
-        setup_kwarg = 'cmake_install_dir=\'{}\''.format(cmake_install_dir)
+        setup_kwarg = 'cmake_install_dir=r\'{}\''.format(cmake_install_dir)
 
     tmp_dir.join('setup.py').write(textwrap.dedent(
         """
@@ -220,13 +221,13 @@ def test_cmake_install_dir_keyword(
         if error_code_type == str:
             assert message == "error: package directory " \
                               "'{}' does not exist".format(
-                                    os.path.join(CMAKE_INSTALL_DIR, 'banana'))
+                                    os.path.join(CMAKE_INSTALL_DIR(), 'banana'))
         else:
             assert message.strip().startswith(
                 "setup parameter 'cmake_install_dir' "
                 "is set to an absolute path.")
     else:
-        init_py = to_platform_path("{}/banana/__init__.py".format(CMAKE_INSTALL_DIR))
+        init_py = to_platform_path("{}/banana/__init__.py".format(CMAKE_INSTALL_DIR()))
         assert "copying {}".format(init_py) in out
 
 
@@ -252,7 +253,7 @@ def test_cmake_with_sdist_keyword(cmake_with_sdist, capfd):
         cmake_minimum_required(VERSION 3.5.0)
         project(test NONE)
         install(CODE "execute_process(
-          COMMAND \${CMAKE_COMMAND} -E sleep 0)")
+          COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
         """
     ))
 
@@ -290,7 +291,7 @@ def test_cmake_minimum_required_version_keyword():
         cmake_minimum_required(VERSION 3.5.0)
         project(test NONE)
         install(CODE "execute_process(
-          COMMAND \${CMAKE_COMMAND} -E sleep 0)")
+          COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
         """
     ))
 
@@ -306,6 +307,11 @@ def test_cmake_minimum_required_version_keyword():
         assert "CMake version 99.98.97 or higher is required." in message
 
 
+@pytest.mark.skipif(os.environ.get("CONDA_BUILD", "0") == "1",
+                    reason="running tests expecting network connection in Conda is not possible. "
+                           "See https://github.com/conda/conda/issues/508")
+@pytest.mark.skipif(not is_site_reachable("https://pypi.org/simple/cmake/"),
+                    reason="pypi.org website not reachable")
 def test_setup_requires_keyword_include_cmake(mocker, capsys):
 
     mock_setup = mocker.patch('skbuild.setuptools_wrap.upstream_setup')
@@ -332,7 +338,7 @@ def test_setup_requires_keyword_include_cmake(mocker, capsys):
         cmake_minimum_required(VERSION 3.5.0)
         project(test NONE)
         install(CODE "execute_process(
-          COMMAND \${CMAKE_COMMAND} -E sleep 0)")
+          COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
         """
     ))
 
@@ -408,7 +414,7 @@ def test_script_keyword(distribution_type, capsys):
 
         messages = [
             "copying {}/{}.py -> "
-            "{}/setuptools/scripts-".format(CMAKE_INSTALL_DIR, module, SKBUILD_DIR)
+            "{}/setuptools/scripts-".format(CMAKE_INSTALL_DIR(), module, SKBUILD_DIR())
             for module in ['foo', 'bar']]
 
     elif distribution_type == 'pure':
@@ -417,7 +423,7 @@ def test_script_keyword(distribution_type, capsys):
 
         messages = [
             "copying {}.py -> "
-            "{}/setuptools/scripts-".format(module, SKBUILD_DIR)
+            "{}/setuptools/scripts-".format(module, SKBUILD_DIR())
             for module in ['foo', 'bar']]
 
     with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
@@ -488,7 +494,7 @@ def test_py_modules_keyword(distribution_type, capsys):
 
         messages = [
             "copying {}/{}.py -> "
-            "{}/setuptools/lib".format(CMAKE_INSTALL_DIR, module, SKBUILD_DIR)
+            "{}/setuptools/lib".format(CMAKE_INSTALL_DIR(), module, SKBUILD_DIR())
             for module in ['foo', 'bar']]
 
     elif distribution_type == 'pure':
@@ -497,7 +503,7 @@ def test_py_modules_keyword(distribution_type, capsys):
 
         messages = [
             "copying {}.py -> "
-            "{}/setuptools/lib".format(module, SKBUILD_DIR)
+            "{}/setuptools/lib".format(module, SKBUILD_DIR())
             for module in ['foo', 'bar']]
 
     with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
@@ -543,7 +549,7 @@ def test_setup_inputs(
 
     tmp_dir = _tmpdir('test_setup_inputs')
 
-    package_base = 'base' if with_package_base else ''
+    package_base = 'to/the/base' if with_package_base else ''
     package_base_dir = package_base + '/' if package_base else ''
     cmake_source_dir = package_base
 
@@ -827,7 +833,7 @@ def test_setup_inputs(
 
         # package dir
         expected_package_dir = {
-            package: (os.path.join(CMAKE_INSTALL_DIR,
+            package: (os.path.join(CMAKE_INSTALL_DIR(),
                       package_base,
                       package.replace('.', '/')))
             for package in expected_packages
@@ -1013,7 +1019,7 @@ def test_cmake_install_into_pure_package(with_cmake_source_dir, capsys):
 
     messages = [
         "copying {}/{} -> "
-        "{}/setuptools/lib".format(CMAKE_INSTALL_DIR, module, SKBUILD_DIR)
+        "{}/setuptools/lib".format(CMAKE_INSTALL_DIR(), module, SKBUILD_DIR())
         for module in [
             'fruits/__init__.py',
             'fruits/apple.py',
@@ -1025,3 +1031,51 @@ def test_cmake_install_into_pure_package(with_cmake_source_dir, capsys):
     out, _ = capsys.readouterr()
     for message in messages:
         assert to_platform_path(message) in out
+
+
+@pytest.mark.parametrize("zip_safe", [None, False, True])
+def test_zip_safe_default(zip_safe, mocker):
+
+    mock_setup = mocker.patch('skbuild.setuptools_wrap.upstream_setup')
+
+    tmp_dir = _tmpdir('zip_safe_default')
+
+    setup_kwarg = ''
+    if zip_safe is not None:
+        setup_kwarg = 'zip_safe={}'.format(zip_safe)
+
+    tmp_dir.join('setup.py').write(textwrap.dedent(
+        """
+        from skbuild import setup
+        setup(
+            name="zip_safe_default",
+            version="1.2.3",
+            description="a minimal example package",
+            author='The scikit-build team',
+            license="MIT",
+            {setup_kwarg}
+        )
+        """.format(setup_kwarg=setup_kwarg)
+    ))
+    tmp_dir.join('CMakeLists.txt').write(textwrap.dedent(
+        """
+        cmake_minimum_required(VERSION 3.5.0)
+        project(test NONE)
+        install(CODE "execute_process(
+          COMMAND \\${CMAKE_COMMAND} -E sleep 0)")
+        """
+    ))
+
+    with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
+        pass
+
+    assert mock_setup.call_count == 1
+    setup_kw = mock_setup.call_args[1]
+
+    assert "zip_safe" in setup_kw
+    if zip_safe is None:
+        assert not setup_kw["zip_safe"]
+    elif zip_safe:
+        assert setup_kw["zip_safe"]
+    else:  # zip_safe is False
+        assert not setup_kw["zip_safe"]
